summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/delete.h
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/exec/delete.h
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/exec/delete.h')
-rw-r--r--src/mongo/db/exec/delete.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/exec/delete.h b/src/mongo/db/exec/delete.h
index 12a62697261..aa7512eb1e8 100644
--- a/src/mongo/db/exec/delete.h
+++ b/src/mongo/db/exec/delete.h
@@ -58,7 +58,7 @@ namespace mongo {
};
/**
* This stage delete documents by DiskLoc that are returned from its child. NEED_TIME
* is returned after deleting a document.
*
* Callers of work() must be holding a write lock (and, for shouldCallLogOp=true deletes,
@@ -79,7 +79,7 @@ namespace mongo {
virtual void saveState();
virtual void restoreState(OperationContext* opCtx);
- virtual void invalidate(OperationContext* txn, const DiskLoc& dl, InvalidationType type);
+ virtual void invalidate(OperationContext* txn, const RecordId& dl, InvalidationType type);
virtual std::vector<PlanStage*> getChildren() const;
@@ -58,7 +58,7 @@ namespace mongo {
};
/**
- * This stage delete documents by DiskLoc that are returned from its child. NEED_TIME
+ * This stage delete documents by RecordId that are returned from its child. NEED_TIME
* is returned after deleting a document.
*